@@ -329,6 +329,7 @@ class CfsClient(AbstractClient):
 
     def DeleteMountTarget(self, request):
         """本接口（DeleteMountTarget）用于删除挂载点
+        说明：2022年6月1日之后创建的CFS文件系统删除时无需单独调用删除挂载点操作，此API仅适用老版本的CFS实例。
 
         :param request: Request instance for DeleteMountTarget.
         :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteMountTargetRequest`
@@ -998,7 +999,7 @@ class CfsClient(AbstractClient):
 
 
     def UpdateFileSystemBandwidthLimit(self, request):
-        """更新文件系统带宽
+        """更新文件系统吞吐
         仅吞吐型支持此接口
 
         :param request: Request instance for UpdateFileSystemBandwidthLimit.
