@@ -72,7 +72,7 @@ class AddCrossVpcSubnetSupportForClientNodeResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -144,7 +144,7 @@ class AttachFileSystemBucketResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -231,7 +231,7 @@ class BatchAddClientNodesResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -318,7 +318,7 @@ class BatchDeleteClientNodesResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -706,7 +706,7 @@ class CreateDataRepositoryTaskResponse(AbstractModel):
         r"""
         :param _TaskId: 任务ID
         :type TaskId: str
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._TaskId = None
@@ -757,6 +757,8 @@ class CreateFileSystemRequest(AbstractModel):
         :type Tag: list of Tag
         :param _GooseFSxBuildElements: GooseFSx构建时要传递的参数
         :type GooseFSxBuildElements: :class:`tencentcloud.goosefs.v20220519.models.GooseFSxBuildElement`
+        :param _SecurityGroupId: 客户端集群所属的安全组
+        :type SecurityGroupId: str
         """
         self._Type = None
         self._Name = None
@@ -766,6 +768,7 @@ class CreateFileSystemRequest(AbstractModel):
         self._Zone = None
         self._Tag = None
         self._GooseFSxBuildElements = None
+        self._SecurityGroupId = None
 
     @property
     def Type(self):
@@ -831,6 +834,14 @@ class CreateFileSystemRequest(AbstractModel):
     def GooseFSxBuildElements(self, GooseFSxBuildElements):
         self._GooseFSxBuildElements = GooseFSxBuildElements
 
+    @property
+    def SecurityGroupId(self):
+        return self._SecurityGroupId
+
+    @SecurityGroupId.setter
+    def SecurityGroupId(self, SecurityGroupId):
+        self._SecurityGroupId = SecurityGroupId
+
 
     def _deserialize(self, params):
         self._Type = params.get("Type")
@@ -848,6 +859,7 @@ class CreateFileSystemRequest(AbstractModel):
         if params.get("GooseFSxBuildElements") is not None:
             self._GooseFSxBuildElements = GooseFSxBuildElement()
             self._GooseFSxBuildElements._deserialize(params.get("GooseFSxBuildElements"))
+        self._SecurityGroupId = params.get("SecurityGroupId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -865,7 +877,7 @@ class CreateFileSystemResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -937,7 +949,7 @@ class DeleteCrossVpcSubnetSupportForClientNodeResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -995,7 +1007,7 @@ class DeleteFileSystemResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -1055,7 +1067,7 @@ class DescribeClientNodesResponse(AbstractModel):
         r"""
         :param _ClientNodes: 客户端节点数组
         :type ClientNodes: list of ClientNodeAttribute
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._ClientNodes = None
@@ -1130,7 +1142,7 @@ class DescribeClusterClientTokenResponse(AbstractModel):
         r"""
         :param _ClientTokens: 客户端凭证
         :type ClientTokens: list of ClientToken
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._ClientTokens = None
@@ -1217,7 +1229,7 @@ class DescribeClusterRoleTokenResponse(AbstractModel):
         r"""
         :param _RoleTokens: 角色凭证
         :type RoleTokens: list of RoleToken
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RoleTokens = None
@@ -1304,7 +1316,7 @@ class DescribeClusterRolesResponse(AbstractModel):
         r"""
         :param _ClusterRoles: 集群角色
         :type ClusterRoles: list of ClusterRole
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._ClusterRoles = None
@@ -1397,7 +1409,7 @@ class DescribeDataRepositoryTaskStatusResponse(AbstractModel):
         :type FinishedFileNumber: int
         :param _FinishedCapacity: 已完成的数据量
         :type FinishedCapacity: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._TaskId = None
@@ -1497,7 +1509,7 @@ class DescribeFileSystemBucketsResponse(AbstractModel):
         r"""
         :param _BucketList: bucket列表
         :type BucketList: list of MappedBucket
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._BucketList = None
@@ -1586,7 +1598,7 @@ class DescribeFileSystemsResponse(AbstractModel):
         :type FSAttributeList: list of FSAttribute
         :param _TotalCount: 总共的文件系统数量
         :type TotalCount: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._FSAttributeList = None
@@ -1681,7 +1693,7 @@ class DetachFileSystemBucketResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -1751,7 +1763,7 @@ class ExpandCapacityResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -1952,7 +1964,7 @@ class GooseFSxAttribute(AbstractModel):
         r"""
         :param _Model: GooseFSx的型号
         :type Model: str
-        :param _Capacity: 容量单位是GB, 比如4608(4.5TB)
+        :param _Capacity: 容量单位是GB, 例如4608(4.5TB)
         :type Capacity: int
         :param _MappedBucketList: 要关联映射的bucket列表
         :type MappedBucketList: list of MappedBucket
@@ -2031,7 +2043,7 @@ class GooseFSxBuildElement(AbstractModel):
         r"""
         :param _Model: GooseFSx的型号
         :type Model: str
-        :param _Capacity: 容量单位是GB, 比如4608(4.5TB)
+        :param _Capacity: 容量单位是GB, 例如4608(4.5TB)
         :type Capacity: int
         :param _MappedBucketList: 要关联映射的bucket列表
         :type MappedBucketList: list of MappedBucket
@@ -2180,12 +2192,23 @@ class MappedBucket(AbstractModel):
         :param _RuleDescription: 规则备注与描述
 注意：此字段可能返回 null，表示取不到有效值。
         :type RuleDescription: str
+        :param _Status: 桶关联状态 0：关联中 1：关联完成
+        :type Status: int
+        :param _AccelerateFlag: 是否使用全球加速域名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AccelerateFlag: bool
+        :param _BucketRegion: 桶所在的园区
+注意：此字段可能返回 null，表示取不到有效值。
+        :type BucketRegion: str
         """
         self._BucketName = None
         self._FileSystemPath = None
         self._DataRepositoryTaskAutoStrategy = None
         self._RuleId = None
         self._RuleDescription = None
+        self._Status = None
+        self._AccelerateFlag = None
+        self._BucketRegion = None
 
     @property
     def BucketName(self):
@@ -2227,6 +2250,30 @@ class MappedBucket(AbstractModel):
     def RuleDescription(self, RuleDescription):
         self._RuleDescription = RuleDescription
 
+    @property
+    def Status(self):
+        return self._Status
+
+    @Status.setter
+    def Status(self, Status):
+        self._Status = Status
+
+    @property
+    def AccelerateFlag(self):
+        return self._AccelerateFlag
+
+    @AccelerateFlag.setter
+    def AccelerateFlag(self, AccelerateFlag):
+        self._AccelerateFlag = AccelerateFlag
+
+    @property
+    def BucketRegion(self):
+        return self._BucketRegion
+
+    @BucketRegion.setter
+    def BucketRegion(self, BucketRegion):
+        self._BucketRegion = BucketRegion
+
 
     def _deserialize(self, params):
         self._BucketName = params.get("BucketName")
@@ -2234,6 +2281,9 @@ class MappedBucket(AbstractModel):
         self._DataRepositoryTaskAutoStrategy = params.get("DataRepositoryTaskAutoStrategy")
         self._RuleId = params.get("RuleId")
         self._RuleDescription = params.get("RuleDescription")
+        self._Status = params.get("Status")
+        self._AccelerateFlag = params.get("AccelerateFlag")
+        self._BucketRegion = params.get("BucketRegion")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -2296,7 +2346,7 @@ class ModifyDataRepositoryBandwidthResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -2356,7 +2406,7 @@ class QueryCrossVpcSubnetSupportForClientNodeResponse(AbstractModel):
         r"""
         :param _SubnetInfoCollection: 支持的子网信息集合
         :type SubnetInfoCollection: list of SubnetInfo
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._SubnetInfoCollection = None
@@ -2435,7 +2485,7 @@ class QueryDataRepositoryBandwidthResponse(AbstractModel):
         :type BandwidthStatus: int
         :param _MinBandwidth: 能设置的最小带宽, 单位MB/s
         :type MinBandwidth: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Bandwidth = None
